OC.L10N.register(
    "notes",
    {
    "Notes" : "Бележки",
    "The last viewed note cannot be accessed. " : "Последно отворената бележка не е достъпна.",
    "The notes folder is not accessible: %s" : "Папката с бележки не е достъпна: %s",
    "New note" : "Нова бележка",
    "Encryption Error" : "Encryption Error",
    "Error" : "Грешка",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Има незаписани бележки. Напускайте тази страница, направени промени ще бъдат загубени!",
    "Settings" : "Настройки",
    "Folder to store your notes" : "Папка за съхранение на бележките",
    "path to notes" : "път до бележките",
    "File extension for new notes" : "Разширение за файловете",
    "All notes" : "Всички бележки",
    "Categories" : "Категории",
    "Today" : "Днес",
    "Yesterday" : "Вчера",
    "This week" : "Тази седмица",
    "This month" : "Този месец",
    "Delete note" : "Изтрий бележката",
    "Remove from favorites" : "Премахни от любимите",
    "Add to favorites" : "Добави към любимите",
    "Details" : "Подробности",
    "Preview" : "Преглед",
    "Edit" : "Променяне",
    "Category" : "Категория",
    "Uncategorized" : "Некатегоризирана",
    "Saving failed!" : "Записването се провали!",
    "_%n word_::_%n words_" : ["%n дума","%n думи"],
    "Android app" : "Android приложение",
    "iOS app" : "iOS приложениер",
    "Updating the note's category has failed. Is the target directory writable?" : "Неуспешен опит за промяна на категорията. Може ли да се пише в папката на бележките?"
},
"nplurals=2; plural=(n != 1);");
